@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20230428';
+our $VERSION = '0.20230531';
 
-# Table last modified: 2023-04-28
+# Table last modified: 2023-05-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -42,7 +42,7 @@ our %ZIP_TABLE = (
     '036' => '(?:(?:8(?:5(?:11|22|45|77|0[1-3]|6[0-47]|5[0158]|8[58]|3[038])|6(?:01|42|55|66|8[689])|7(?:77|88))|1(?:59[23]|393|492)|039[26]))',
     '037' => '(?:(?:86(?:01|55|86)|0392))',
     '038' => '(?:(?:3(?:19[2-5]|39[2-4]|[68]92|595)|85(?:[08]5|[56]0)|0(?:19[24]|292)|139[23]|279[23]))',
-    '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|49[23]|79[23]|[13]92|696)|0(?:19[58]|59[25]|[28]92)|11(?:9[237]|8[0159])|4(?:29[23]|495|692)|3393))',
+    '039' => '(?:(?:2(?:2(?:9[23]|8[0-35-79])|59[2-578]|49[23]|79[23]|[13]92|696)|11(?:9[237]|8[0159])|0(?:[258]92|19[58])|4(?:29[23]|495|692)|3393))',
     '040' => '(?:8(?:5(?:77|3[03]|4[13]|5[0-258]|2[02]|8[0158]|1[0-2]|0[125]|6[017])|6(?:55|70|4[02]|[68][068]|3[12]|0[1-359]|1[016])|7(?:[12][07])))',
     '041' => '(?:(?:8(?:5(?:01|40|77|2[23]|8[89]|1[0-25]|6[07]|5[1-8])|6(?:[23]3|48|55|80|1[01])|711)|1(?:19[2-6]|49[6-8]|[36]92)))',
     '042' => '(?:8(?:5(?:[01]1|55|67|8[58])|6(?:39|42|78)))',
@@ -104,17 +104,17 @@ our %ZIP_TABLE = (
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|0[2367]|4[15]|1[01]|3[1-358]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
-    '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|0[57-9]|8[0135]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-25689])|3(?:6[2356]|0[12578]|7[0-258]|8[1358]|1[013-8]|5[0-689]|3[13568]|4[35-7]|2[13-9])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
+    '101' => '(?:8(?:4(?:7[05-7]|1[0568]|6[0-246]|4[14-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:6[26]|1[01358]|8[38]|0[178]|5[013-589]|4[367]|3[3568]|2[3-69]|7[258])|9(?:01|50|7[0-37]|4[16]|8[36])|7(?:0[137]|1[0-25-8])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
     '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|8[024578]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:70|3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|5(?:72|1[028]|8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|4[35-8]|0[1256])|2(?:38|40|71|6[26]|5[0-24578]|1[0-258]|0[568]|8[0-59])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
-    '105' => '(?:(?:8(?:5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|6[014-689]|4[014-9]|2[0347-9]|1[0-24-9]|0[1-378])|6(?:7[026-8]|3[04]|6[0568]|8[015689]|2[0135-7]|5[468]|1[013-57]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:[58]0|77)|444)|6[09]50))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:72|1[028]|8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|4[35-8]|0[1256])|4(?:3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[0-24578]|1[0-258]|0[568]|8[0-59])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
+    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-57-9])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:[58]0|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])|797))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|0[1-46-9]|8[0-3568])|3(?:2[25689]|7[2359]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|0[1-46-9]|8[0-3568])|3(?:2[25689]|1[0356]|7[2359]|8[013-689]|3[34]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
-    '111' => '(?:8(?:5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|6(?:4[028]|3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05])|7(?:[56]5|21|98|0[178]|1[01])|081))',
+    '111' => '(?:8(?:6(?:3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|6[2369]|1[1246]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|0[1-468]|8[16]|1[0-2]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
@@ -130,10 +130,10 @@ our %ZIP_TABLE = (
     '132' => '(?:8(?:5(?:[18]5|33|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
     '134' => '(?:8(?:5(?:[15]5|20|33|7[05-7]|8[5-8]|0[237])|6(?:22|86|[14][02]|0[1-39]|3[01])|702))',
-    '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[136]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|45|50|1[01458]|0[89]|3[0479]|8[01])|7(?:3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
+    '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:[46]5|21|50|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|8[0346]|7[1-36]|6[0367]|2[1-3569]|0[235-9]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
+    '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|8[0346]|6[0367]|2[1-3569]|0[235-9]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
     '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:88|1[1-3689]|2[0-6])|2(?:14|55|60|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
@@ -149,17 +149,17 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
     '157' => '(?:85(?:43|50|6[1-35-7]|3[05]|0[18]|2[0-2]|7[0357]|1[01]))',
     '158' => '(?:8(?:5(?:3[1349]|5[0-278]|8[0568]|1[0-48]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|0[14689]|[24][17]|1[169]|6[168]|5[1-38])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|4[37]|0[17]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
+    '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|1[1369]|0[14689]|[24][17]|6[168]|5[1-38])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|4[37]|0[17]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
-    '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[0568]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
-    '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|87|6[18])|9(?:43|3[68])|4(?:56|78)|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|26|80|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
+    '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
+    '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|87|6[18])|9(?:43|3[68])|4(?:56|78)|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|80|2[06]|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
     '164' => '(?:8(?:6(?:[25]0|66|8[26]|7[78]|1[167]|4[24]|[03][18])|5(?:[37]0|12|67|4[015]|2[25]|8[58]|5[05]|0[13-5])|7(?:25|0[15])))',
     '165' => '(?:8(?:(?:63|78)0|555))',
     '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
     '167' => '(?:8(?:5(?:[26]0|34|85|0[15-7]|1[05]|5[15])|6(?:10|28|0[12])|001))',
     '168' => '(?:8(?:5(?:[6-8]0|48|1[0-26]|5[058]|2[05]|0[13468]|3[035])|6(?:2[06]|[18][16]|0[18])|081))',
     '169' => '(?:8(?:5(?:8[06]|0[39]|2[0-25-7]|5[0568]|1[6-8]|6[18]|7[078]|4[01]|3[15])|6(?:39|77|5[05]|0[58]|1[0-36]|[46][48])|0(?:50|77|1[12])|7(?:[01]1|22)|(?:88|91)5|228))',
-    '170' => '(?:(?:8(?:4(?:1[015-79]|2[013467]|0[124-69]|7[067]|4[0-248]|5[015-9]|6[0256]|8[08]|3[02-468])|6(?:[68]6|55|0[25]|3[35])|0(?:55|73)|5(?:51|85))|6080))',
+    '170' => '(?:(?:8(?:4(?:1[015-79]|7[0467]|2[013467]|0[124-69]|4[0-248]|5[015-9]|6[0256]|8[08]|3[02-468])|6(?:[68]6|55|0[25]|3[35])|0(?:55|73)|5(?:51|85))|6080))',
     '171' => '(?:8(?:5(?:5[23578]|3[19]|7[027]|4[045]|2[0-35-7]|1[0-2468]|6[0189]|0[1-3578]|8[0268])|422))',
     '173' => '(?:8(?:5(?:[06]1|[23]0|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|3[29]|1[01]|0[1256])|710))',
     '174' => '(?:8(?:5(?:[13]0|0[135]|6[027]|5[058]|2[014-6]|8[08])|6(?:12|46|51|3[0369]|8[068]|0[12])|7(?:[01]1|87|3[079]|4[0134])|860|903))',
@@ -211,7 +211,7 @@ our %ZIP_TABLE = (
     '226' => '(?:85(?:[25]5|70|1[02]|0[1-37]))',
     '227' => '(?:85(?:22|40|0[1258]|1[28]))',
     '230' => '(?:8(?:5(?:11|7[17]|0[14]|5[05])|6(?:[68]6|11|28)|765))',
-    '231' => '(?:8(?:5(?:04|6[26]|8[58]|3[0469]|2[08]|4[49]|5[035])|3(?:07|2[01348]|3[0158]|4[036]|1[0-6])|6(?:16|23|31|60|5[124]|8[29])|4(?:[368]4|45|7[78]|1[19])|7(?:7[12]|1[15])|00[18]|831|966))',
+    '231' => '(?:8(?:5(?:04|6[26]|8[58]|3[0469]|2[08]|4[49]|5[035])|3(?:07|2[01348]|3[0158]|4[036]|1[0-6])|6(?:16|23|31|60|5[124]|8[29])|4(?:[368]4|45|7[78]|1[19])|7(?:50|7[12]|1[15])|00[18]|831|966))',
     '232' => '(?:8(?:5(?:31|8[057]|5[58]|1[05])|6(?:02|88)))',
     '233' => '(?:85(?:0[1-3]|5[056]))',
     '235' => '(?:85(?:58|2[23]|0[15]))',
@@ -222,7 +222,7 @@ our %ZIP_TABLE = (
     '240' => '(?:(?:8(?:5(?:[02]1|[45]0)|612)|019[235-8]))',
     '241' => '(?:8(?:5(?:25|1[25]|0[12])|606))',
     '242' => '(?:8(?:5(?:[58]5|77|0[27])|6(?:01|10)))',
-    '243' => '(?:(?:0(?:4(?:60|9[2-7]|8[02-79])|2(?:81|9[278])|19[23578]|392)|8(?:5(?:88|5[015]|3[13]|7[17]|2[12]|1[01]|0[15])|6(?:89|0[14]))))',
+    '243' => '(?:(?:8(?:5(?:88|5[015]|3[13]|7[17]|2[12]|1[01]|0[15])|6(?:89|0[14]))|0(?:4(?:60|9[2-467]|8[02-79])|2(?:81|9[278])|19[23578]|392)))',
     '244' => '(?:8(?:5(?:0[1-3]|7[17]|2[28]|5[058]|8[589]|6[679]|1[01]|3[039])|60[12]))',
     '245' => '(?:8(?:5(?:[16]0|42|89|5[058]|7[57])|65[01]))',
     '246' => '(?:85(?:20|5[06]))',
@@ -253,7 +253,7 @@ our %ZIP_TABLE = (
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
     '275' => '(?:8(?:5(?:02|11|33|[28][058]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
     '276' => '(?:85(?:01|80|2[3-7]))',
-    '277' => '(?:8(?:5(?:6[14-69]|1[1589]|0[13-57]|8[124-9]|5[0146-8]|3[139]|2[0-2]|7[0-479])|6(?:86|5[45]|6[16])))',
+    '277' => '(?:8(?:5(?:1[1589]|0[13-57]|8[124-9]|5[0146-8]|3[139]|2[0-2]|7[0-479]|6[1-69])|6(?:86|5[45]|6[16])))',
     '278' => '(?:8(?:5(?:[02]1|10|33|7[07]|5[05])|6(?:01|86)))',
     '279' => '(?:8(?:5(?:41|67|5[0358]|8[0-358]|0[1-356]|2[124-69]|1[16-9]|3[0-2])|6(?:01|86)))',
     '282' => '(?:86(?:02|10))',
@@ -297,7 +297,7 @@ our %ZIP_TABLE = (
     '321' => '(?:(?:3(?:29[235-8]|39[2358]|49[378]|59[578])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[238]|49[23])|85(?:[58]5|0[25])))',
     '322' => '(?:(?:8(?:5(?:11|0[1-3]|8[58]|5[05])|6(?:66|88|0[13]))|0(?:393|692)))',
     '323' => '(?:(?:8(?:5(?:11|58|67|8[56])|6(?:[01]1|78|86)|75[56])|019[24]|1192))',
-    '324' => '(?:(?:8(?:5(?:[24]0|01|85|1[06]|5[015])|6(?:25|86|4[12]))|0(?:59[2-6]|29[23]|69[23]|492)))',
+    '324' => '(?:(?:8(?:5(?:[24]0|01|85|1[06]|5[015])|6(?:25|86|4[12])|765)|0(?:59[2-6]|29[23]|69[23]|492)))',
     '325' => '(?:039[23578])',
     '326' => '(?:(?:8(?:5(?:11|72|85|5[08]|2[01]|0[125])|6(?:[01]1|30|86))|039[25]))',
     '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
@@ -340,7 +340,7 @@ our %ZIP_TABLE = (
     '364' => '(?:8(?:5(?:[01]1|[58]5)|633))',
     '365' => '(?:8(?:5(?:85|1[24]|0[1-3568])|60[13]))',
     '366' => '(?:85(?:[28]1|67|1[015]|0[12]))',
-    '367' => '(?:(?:0(?:29[26-8]|19[248])|8(?:501|686)))',
+    '367' => '(?:(?:0(?:29[26-8]|19[248]|393)|8(?:501|686)))',
     '368' => '(?:(?:8(?:6(?:66|8[06])|50[125])|0(?:19[235]|292)))',
     '369' => '(?:(?:1(?:29[2358]|89[2-5]|19[235]|59[236]|[34]92|998)|0(?:29[2357]|19[258]|39[235])))',
     '370' => '(?:(?:8(?:5(?:[01]1|[68]5|22|43|3[17]|5[05])|6(?:[01]1|22|86|6[68]))|1(?:39[2-6]|19[2356]|29[23]|592)|0(?:59[568]|49[25]|193|692|795)|2(?:39[23568]|49[58]|[12]92)|3(?:59[2-4]|[146]92|39[23])))',
@@ -348,7 +348,7 @@ our %ZIP_TABLE = (
     '372' => '(?:8(?:5(?:10|58|67|8[058]|0[128])|686))',
     '373' => '(?:8(?:5(?:21|78|1[0-35]|0[1589]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|[68][068]|1[01])|718))',
     '374' => '(?:(?:8(?:5(?:01|20|33|55|77|88|1[0-28])|6(?:11|22|40|86|0[18]))|019[23]))',
-    '375' => '(?:8(?:50[1-6]|60[1-4]))',
+    '375' => '(?:8(?:50[1-7]|60[1-4]))',
     '376' => '(?:(?:8(?:5(?:31|85|1[056]|2[38]|5[58]|0[12])|6(?:86|6[68]))|0(?:19[2-4]|39[27])))',
     '377' => '(?:(?:0(?:8(?:8[23]|9[2-46-8])|2(?:80|9[2-4])|19[235]|39[25]|49[24]|792)|8(?:5(?:[67]7|20|33|55|1[013]|0[1-38]|8[58])|616)|1(?:79[2-7]|39[235]|59[3-5]|69[235])))',
     '378' => '(?:(?:0498|8501))',
@@ -421,7 +421,7 @@ our %ZIP_TABLE = (
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
     '448' => '(?:8(?:6(?:10|22|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:11|50|0[156]|2[35]|3[13-5]|4[023])|731))',
     '449' => '(?:029[23])',
-    '450' => '(?:(?:8(?:5(?:40|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[05]1|[48]0|2[06]|1[1458])|7(?:11|65)|99[35-7])|6(?:(?:13|36)3|660)))',
+    '450' => '(?:(?:8(?:5(?:40|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[248]0|[05]1|1[1458])|7(?:11|65)|99[35-7])|6(?:(?:13|36)3|660)))',
     '451' => '(?:8(?:5(?:[14]1|2[02]|[56][0158]|0[1-38]|7[0157])|6(?:[15]0|66|88)|701))',
     '452' => '(?:8(?:5(?:70|0[1-3]|6[1-79])|60[12]))',
     '453' => '(?:8(?:5(?:40|8[015]|3[39]|7[07]|5[58]|6[57]|2[12]|0[15]|1[0-28])|6(?:[28]6|11|62|0[18])|7(?:58|65|77|0[124])))',
@@ -437,7 +437,7 @@ our %ZIP_TABLE = (
     '463' => '(?:85(?:10|5[057]|2[128]|8[05]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
     '464' => '(?:8(?:5(?:85|91|4[05-7]|5[058]|2[0-25]|1[12]|6[0167]|3[01369]|7[017])|6(?:[78]1|0[1-3]|4[134]|3[1-357]|6[12]|1[0135-8]|5[0-24])|710))',
     '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:68|70|1[0-2]|5[01]|2[026])))',
-    '466' => '(?:8(?:5(?:40|6[05-7]|3[39]|2[25]|8[058]|1[0-25]|5[0458]|0[125-8])|6(?:10|73|88|6[06]|5[05-7]|3[0356])|7(?:11|0[17])))',
+    '466' => '(?:8(?:5(?:40|6[05-7]|3[39]|2[25]|8[058]|1[0-25]|0[125-7]|5[0458])|6(?:73|88|6[06]|5[05-7]|3[0356])|7(?:11|0[17])))',
     '467' => '(?:8(?:5(?:01|6[1-367]|7[17]|3[013]|8[0158]|5[58]|2[0-2]|1[01])|6(?:51|86|2[26]|0[1-3]|3[39]|1[01])))',
     '468' => '(?:8(?:5(?:51|2[02]|0[1-357]|1[0-4]|8[58]|3[1-467])|626))',
     '469' => '(?:879[367])',
@@ -445,12 +445,12 @@ our %ZIP_TABLE = (
     '471' => '(?:8(?:5(?:7[1-4]|6[056]|3[0-25-7]|0[1-36-8]|1[0-35-8]|8[58]|5[05]|2[1257])|60[1-39]))',
     '472' => '(?:8(?:6(?:[68]6|39)|5[58]5))',
     '473' => '(?:85[01]1)',
-    '474' => '(?:8(?:5(?:35|43|8[01458]|5[0578]|1[01]|0[1-35])|6(?:[05]1|42|66|8[68]|1[01])|7(?:10|66|77|0[17])))',
+    '474' => '(?:8(?:5(?:35|43|8[01458]|5[0578]|1[01]|0[1-35])|6(?:[05]1|42|[68][68]|1[01])|7(?:10|66|77|0[17])))',
     '475' => '(?:8(?:5(?:41|60|74|99|5[057]|2[28]|8[58]|1[01]|0[125])|6(?:[01]1|55|86|6[68])))',
     '476' => '(?:8(?:5(?:[67]7|10|22|33|0[13]|8[58])|6(?:[68]6|01)))',
     '477' => '(?:852[12])',
     '478' => '(?:8(?:5(?:55|0[1-5])|6(?:01|4[01])))',
-    '479' => '(?:8(?:5(?:01|55|77|1[018]|8[5689])|7(?:87|0[1-8]|1[12])|6(?:01|10|23|68)))',
+    '479' => '(?:8(?:5(?:01|55|77|8[5-9]|1[018])|7(?:87|0[1-8]|1[12])|6(?:01|10|23|68)))',
     '480' => '(?:(?:0(?:2(?:8[1278]|9[1-47])|19[23578]|39[235])|1(?:1(?:8[89]|9[2-8])|298)))',
     '481' => '(?:8(?:5(?:26|88|4[03]|5[058]|1[0135]|0[1-68]|3[1359])|6(?:[08]1|15|78)))',
     '482' => '(?:8(?:5(?:01|55|1[01])|6(?:60|86|5[12])))',
@@ -548,7 +548,7 @@ our %ZIP_TABLE = (
     '578' => '(?:85(?:22|55|77|3[35]|8[58]|0[12]|1[15]))',
     '579' => '(?:8502)',
     '580' => '(?:8(?:50[1-5]|601))',
-    '581' => '(?:8(?:5(?:[08]5|11|39|58)|686))',
+    '581' => '(?:8(?:5(?:11|39|58|85|0[25])|686))',
     '582' => '(?:85(?:01|55|8[25]))',
     '583' => '(?:85(?:01|22|63|3[3-5]|8[0358]|5[058]))',
     '584' => '(?:8(?:5(?:[13]1|22|40|85)|651))',
@@ -623,7 +623,7 @@ our %ZIP_TABLE = (
     '657' => '(?:85(?:01|70))',
     '658' => '(?:85(?:01|70|5[58]))',
     '659' => '(?:85(?:11|0[1-3]))',
-    '660' => '(?:85(?:01|33|67|4[04]|5[058]|1[01]|8[0258]))',
+    '660' => '(?:85(?:[01]1|33|67|4[04]|5[058]|8[0258]))',
     '661' => '(?:8(?:5(?:[23]0|01|77|6[47]|5[058]|8[58]|1[01])|661))',
     '662' => '(?:85(?:[34]3|10|21|67|8[056]|5[258]|0[1-35]))',
     '663' => '(?:8(?:5(?:[13]0|[67]7|01|45|58|8[568])|601))',
@@ -658,7 +658,7 @@ our %ZIP_TABLE = (
     '695' => '(?:85(?:77|85|0[125]))',
     '696' => '(?:(?:0(?:19[2358]|393|692)|8510))',
     '697' => '(?:(?:8(?:5(?:01|85|1[12])|686|789)|0492))',
-    '698' => '(?:(?:8(?:50[13-5]|65[01])|0292))',
+    '698' => '(?:(?:8(?:50[13-6]|65[01])|0292))',
     '699' => '(?:(?:0(?:5(?:88|9[23])|19[23]|29[23]|49[26]|69[67]|792)|1(?:39[2-6]|29[23]|592|898)|4(?:29[28]|692)|5(?:292|695)|2598))',
     '700' => '(?:8(?:5(?:2[0-2568]|4[04-69]|7[0-2578]|8[014-69]|0[1-8]|3[0-589]|5[0-24-8]|6[0-27-9]|1[0-24-9])|6(?:6[06]|7[78]|2[01358]|1[014-8]|5[057]|8[016-9]|0[1-8]|4[05]|3[459])|7(?:18|61|94|0[17]|2[27]|3[1-48])))',
     '701' => '(?:(?:0(?:29[25-8]|19[2357]|39[38])|4(?:39[248]|29[23]|59[23])|1(?:19[25]|29[26])|2(?:292|595)|329[23]))',
@@ -673,7 +673,7 @@ our %ZIP_TABLE = (
     '710' => '(?:(?:8(?:5(?:11|43|75|8[158]|5[058]|[36][05]|0[15]|2[0258])|6(?:[347]8|[68]6|22|1[15]|0[125]))|029[2-48]|1398))',
     '711' => '(?:8(?:5(?:20|55|88|6[57]|1[01])|6(?:11|22|8[68])))',
     '712' => '(?:8(?:5(?:25|77|1[1-4]|3[34]|5[058]|8[58]|6[57]|0[125])|6(?:11|33|86)))',
-    '713' => '(?:8(?:5(?:01|50|65|77)|6(?:01|86|6[68])|713))',
+    '713' => '(?:8(?:5(?:01|50|65|77|88)|6(?:01|86|6[68])|713))',
     '714' => '(?:(?:8(?:585|601)|129[78]|0192))',
     '715' => '(?:8(?:50[1-3]|60[1-3]))',
     '716' => '(?:(?:8(?:5(?:11|85|0[18])|601)|0(?:192|295|396)|1[13]92))',
@@ -760,7 +760,7 @@ our %ZIP_TABLE = (
     '799' => '(?:(?:1(?:5(?:8[128]|9[2-68])|39[2-5]|198|692)|2(?:29[2-4]|49[236]|19[25]|39[23]|69[26])|0(?:19[2-7]|49[235-8])|3(?:19[2-68]|79[23]|292)))',
     '800' => '(?:(?:8(?:5(?:10|85|5[05])|6(?:11|86|0[13]))|0(?:2(?:9[346-8]|8[12568])|39[2-6])))',
     '801' => '(?:8(?:5(?:85|5[05]|0[237]|1[01])|601))',
-    '802' => '(?:8(?:5(?:33|8[015]|1[0-257]|0[1278]|5[058]|2[1249]|6[0167]|4[035]|7[017])|6(?:42|51|77|86|0[14])|701))',
+    '802' => '(?:8(?:5(?:33|8[015]|1[0-257]|0[1278]|5[058]|2[124]|6[0167]|4[035]|7[017])|6(?:42|51|77|86|0[14])|701))',
     '803' => '(?:8(?:5(?:20|43|3[0-35]|1[0-37]|6[17]|5[058]|8[068]|0[1458])|6(?:02|30|86|6[06])|787))',
     '804' => '(?:8(?:5(?:[126]0|77|88|0[135]|3[89]|5[08])|601))',
     '805' => '(?:8(?:5(?:[58]5|3[013-689]|2[0178]|0[1357-9]|1[02-468])|6(?:06|25)))',
@@ -769,9 +769,9 @@ our %ZIP_TABLE = (
     '808' => '(?:(?:8(?:5(?:1[045]|5[058]|8[58]|0[125])|606)|0196))',
     '809' => '(?:8501)',
     '810' => '(?:8(?:5(?:3[0-357-9]|1[1-9]|5[135-8]|7[01578]|2[0-578]|0[1-46-9]|8[13-57-9]|4[013-6]|6[0135-8])|6(?:8[035689]|3[134679]|4[28]|6[02-79]|7[03-7]|1[0179]|0[13-9]|2[0-2579]|5[0-6])|7(?:98|2[0-257]|3[14]|0[157]|1[06-8])))',
-    '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[2358]|49[256]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
+    '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[2358]|49[2568]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
     '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|7[025-8]|5[0-79]|[14][0-8]|2[0-24-9]|6[0-25689])|5(?:[1-3578]\d|0[1-9]|6[0-689]|4[0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
-    '813' => '(?:8(?:5(?:29|33|55|68|1[39]|7[78]|0[13]|8[58])|6(?:09|2[36]|8[01])))',
+    '813' => '(?:8(?:5(?:29|33|55|77|1[39]|0[13]|8[58])|6(?:09|2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:65|77|0[135]|8[58]|1[0-2]|2[0245]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
     '815' => '(?:8(?:5(?:33|88|4[06]|0[13]|2[09]|5[05]|1[01])|6(?:[68]6|01)))',
     '816' => '(?:8(?:5(?:[67]7|01|30|[58][05]|1[01])|666))',
@@ -906,7 +906,7 @@ our %ZIP_TABLE = (
     '947' => '(?:(?:8(?:5(?:[58]5|40|0[1-46])|7(?:01|65))|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|59[24]|277|392)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|4(?:19[2-4]|39[278])|2(?:19[2-4]|39[24])|5(?:49[2-4]|292)|039[238]|8492))',
-    '950' => '(?:(?:8(?:5(?:6[05-7]|3[0-3579]|0[1-57]|4[013-578]|1[0-48]|5[0-35-9]|7[0-25-79]|8[0-689]|2[02-4])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[7-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-36-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|3(?:19[578]|393)))',
+    '950' => '(?:(?:8(?:5(?:6[05-7]|3[0-3579]|0[1-57]|4[013-578]|1[0-48]|5[0-35-9]|7[0-25-79]|8[0-689]|2[02-4])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[7-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-36-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|319[578]))',
     '951' => '(?:8(?:5(?:70|4[04]|2[018]|1[0-489]|6[067]|3[01356]|8[0156]|0[2-478]|5[0-6])|6(?:01|40|78|8[056]|5[05]|3[023]|2[029]|1[0-2]|6[68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|50[13])|019[23]))',
